@@ -1,19 +1,25 @@
 import gi
-gi.require_version('Gtk', '3.0')
+
+gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
-from locale import gettext as _
 
 
 class RenameDialog(Gtk.Dialog):
-
     def __init__(self, window, current_name):
         super().__init__(
-            _("Rename tab"), window, Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-            (Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT, Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT)
+            _("Rename tab"),
+            window,
+            Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
+            (
+                Gtk.STOCK_CANCEL,
+                Gtk.ResponseType.REJECT,
+                Gtk.STOCK_OK,
+                Gtk.ResponseType.ACCEPT,
+            ),
         )
         self.entry = Gtk.Entry()
         self.entry.set_text(current_name)
-        self.entry.set_property('can-default', True)
+        self.entry.set_property("can-default", True)
         self.entry.show()
 
         vbox = Gtk.VBox()
@@ -33,19 +39,20 @@ class RenameDialog(Gtk.Dialog):
 
 class PromptQuitDialog(Gtk.MessageDialog):
 
-    """Prompts the user whether to quit/close a tab.
-    """
+    """Prompts the user whether to quit/close a tab."""
 
     def __init__(self, parent, procs, tabs, notebooks):
-        super(PromptQuitDialog, self).__init__(
-            parent, Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-            Gtk.MessageType.QUESTION, Gtk.ButtonsType.YES_NO
+        super().__init__(
+            parent,
+            Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
+            Gtk.MessageType.QUESTION,
+            Gtk.ButtonsType.YES_NO,
         )
 
         if tabs == -1:
             primary_msg = _("Do you want to close the tab?")
-            tab_str = ''
-            notebooks_str = ''
+            tab_str = ""
+            notebooks_str = ""
         else:
             primary_msg = _("Do you really want to quit Guake?")
             if tabs == 1:
@@ -53,9 +60,9 @@ class PromptQuitDialog(Gtk.MessageDialog):
             else:
                 tab_str = _(" and {0} tabs open").format(tabs)
             if notebooks > 1:
-                notebooks_str = _(' on {0} workspaces').format(notebooks)
+                notebooks_str = _(" on {0} workspaces").format(notebooks)
             else:
-                notebooks_str = ''
+                notebooks_str = ""
 
         if procs == 0:
             proc_str = _("There are no processes running")
@@ -65,11 +72,10 @@ class PromptQuitDialog(Gtk.MessageDialog):
             proc_str = _("There are {0} processes still running").format(procs)
 
         self.set_markup(primary_msg)
-        self.format_secondary_markup("<b>{0}{1}{2}.</b>".format(proc_str, tab_str, notebooks_str))
+        self.format_secondary_markup(f"<b>{proc_str}{tab_str}{notebooks_str}.</b>")
 
     def quit(self):
-        """Run the "are you sure" dialog for quitting Guake
-        """
+        """Run the "are you sure" dialog for quitting Guake"""
         # Stop an open "close tab" dialog from obstructing a quit
         response = self.run() == Gtk.ResponseType.YES
         self.destroy()
@@ -87,12 +93,45 @@ class PromptQuitDialog(Gtk.MessageDialog):
         return response
 
 
-class SaveTerminalDialog(Gtk.FileChooserDialog):
+class PromptResetColorsDialog(Gtk.MessageDialog):
 
+    """Prompts the user whether to reset tab colors."""
+
+    def __init__(self, parent):
+        super().__init__(
+            parent,
+            Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
+            Gtk.MessageType.QUESTION,
+            Gtk.ButtonsType.YES_NO,
+        )
+
+        primary_msg = _("Do you want to reset custom colors for this tab?")
+
+        self.set_markup(primary_msg)
+
+    def reset_tab_custom_colors(self):
+        """Run the "are you sure" dialog for resetting tab colors"""
+        # Stop an open "close tab" dialog from obstructing a quit
+        response = self.run() == Gtk.ResponseType.YES
+        self.destroy()
+        # Keep Guake focussed after dismissing tab-close prompt
+        # if tab == -1:
+        #     self.window.present()
+        return response
+
+
+class SaveTerminalDialog(Gtk.FileChooserDialog):
     def __init__(self, terminal, window):
         super().__init__(
-            _("Save to..."), window, Gtk.FileChooserAction.SAVE,
-            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
+            _("Save to..."),
+            window,
+            Gtk.FileChooserAction.SAVE,
+            (
+                Gtk.STOCK_CANCEL,
+                Gtk.ResponseType.CANCEL,
+                Gtk.STOCK_SAVE,
+                Gtk.ResponseType.OK,
+            ),
         )
         self.set_default_response(Gtk.ResponseType.OK)
         self.terminal = terminal
@@ -121,6 +160,6 @@ class SaveTerminalDialog(Gtk.FileChooserDialog):
         response = super().run()
         if response == Gtk.ResponseType.OK:
             filename = self.get_filename()
-            with open(filename, "w") as f:
+            with open(filename, "w", encoding="utf-8") as f:
                 f.write(selection)
         self.destroy()
