@@ -186,6 +186,10 @@ HOTKEYS = [
         "key": "extra",
         "keys": [
             {"key": "search-on-web", "label": _("Search selected text on web")},
+            {
+                "key": "open-link-under-terminal-cursor",
+                "label": _("Open URL under terminal cursor"),
+            },
         ],
     },
 ]
@@ -247,6 +251,10 @@ class PrefsCallbacks:
         """Changes the activity of save-tabs-when-changed in dconf"""
         self.settings.general.set_boolean("save-tabs-when-changed", chk.get_active())
 
+    def on_load_guake_yml_toggled(self, chk):
+        """Changes the activity of load-guake-yml"""
+        self.settings.general.set_boolean("load-guake-yml", chk.get_active())
+
     def on_default_shell_changed(self, combo):
         """Changes the activity of default_shell in dconf"""
         citer = combo.get_active_iter()
@@ -1008,6 +1016,10 @@ class PrefsDialog(SimpleGladeApp):
         value = self.settings.general.get_boolean("save-tabs-when-changed")
         self.get_widget("save-tabs-when-changed").set_active(value)
 
+        # save tabs when changed
+        value = self.settings.general.get_boolean("load-guake-yml")
+        self.get_widget("load-guake-yml").set_active(value)
+
         # login shell
         value = self.settings.general.get_boolean("use-login-shell")
         self.get_widget("use_login_shell").set_active(value)
