@@ -35,7 +35,7 @@ fi
 
 if [[ $RUN == "1" ]]; then
     echo "Install packages needed for execution"
-    sudo apt install -y \
+    sudo apt-get install --no-install-recommends -y \
         gir1.2-keybinder-3.0 \
         gir1.2-notify-0.7 \
         gir1.2-vte-2.91 \
@@ -46,13 +46,14 @@ if [[ $RUN == "1" ]]; then
         python3-cairo \
         python3-dbus \
         python3-gi \
-        python3-pbr \
-        python3-pip
+        python3-setuptools-scm \
+        python3-pip \
+        libgirepository1.0-dev
 fi
 
 if [[ $MAKE == "1" ]]; then
     echo "Install packages needed for making guake"
-    sudo apt install -y \
+    sudo apt-get install --no-install-recommends -y \
         gettext \
         gsettings-desktop-schemas \
         make \
@@ -61,7 +62,7 @@ fi
 
 if [[ $DEV == "1" ]]; then
     echo "Install needed development packages"
-    sudo apt install -y \
+    sudo apt-get install --no-install-recommends -y \
         aspell-fr \
         colortest \
         dconf-editor \
@@ -72,6 +73,6 @@ fi
 
 if [[ $OPT == "1" ]]; then
     echo "Install packages optional for execution"
-    sudo apt install -y \
+    sudo apt-get install --no-install-recommends -y \
         numix-gtk-theme
 fi
